*************
Citing Alpaca
*************
To refer to the Alpaca software package in publications, please use:

Alpaca (`doi:10.5281/zenodo.10276510 <https://doi.org/10.5281/zenodo.10276510>`_; `RRID:SCR_023739 <https://scicrunch.org/resolver/RRID:SCR_023739>`_)

To cite a specific version of Alpaca please see version-specific DOIs at:

 `doi:10.5281/zenodo.10276510 <https://doi.org/10.5281/zenodo.10276510>`_

To cite Alpaca, please use:

**Köhler CA, Ulianych D, Grün S, Decker S, Denker M (2023)
Facilitating the sharing of electrophysiology data analysis results through in-depth provenance capture. arXiv:2311.09672.
doi:10.48550/arXiv.2311.09672**

A BibTeX entry for LaTeX users is:

.. code-block:: none

    @misc{alpaca23,
          title={Facilitating the sharing of electrophysiology data analysis results through in-depth provenance capture},
          author={Cristiano André Köhler and Danylo Ulianych and Sonja Grün and Stefan Decker and Michael Denker},
          year={2023},
          eprint={2311.09672},
          archivePrefix={arXiv},
          primaryClass={q-bio.NC}
    }
